import WPJSBase from "../Base/WPJSBase";
import UserDataType from "../Types/Data/UserDataType";
/**
 * User class.
 *
 * @since 2.0.0
 */
export default class User<T = UserDataType[] | UserDataType> extends WPJSBase<T> {
    constructor(endpoint?: string);
    /**
     * Set the userId.
     * @param userId
     * @since 2.0.0
     * @example
     * import {User} from "@quickdevelopment/wp-js";
     *
     * const user = new User();
     *
     * user.byUserId(1).get().then((user) => {
     *   console.log(user);
     * })
     */
    byUserId(userId: number): this;
    /**
     * Get a single user.
     * @since 2.0.0
     * @example
     * import {User} from "@quickdevelopment/wp-js";
     *
     * const user = new User('users/1');
     *
     * user.fetch().then((user) => {
     *  console.log(user);
     * })
     */
    fetch(): Promise<T | T[]>;
}
